guix_mirror_bot pushed a commit to branch master
in repository guix.
commit 5b8ffb974c1465591a0e2c29d9547ffdae1dc852
Author: Gabriel Wicki <[email protected]>
AuthorDate: Sun Jul 20 11:11:32 2025 +0200
gnu: kitty: Fix build with GCC@14.
* gnu/packages/terminals.scm (kitty)[arguments] <phases>: Add CFLAGS
argument
ignoring warning.
Change-Id: I29e13b356cabcdb2e4de9ad9fb03fddd786df15c
---
gnu/packages/terminals.scm | 7 +++++--
1 file changed, 5 insertions(+), 2 deletions(-)
diff --git a/gnu/packages/terminals.scm b/gnu/packages/terminals.scm
index 0c877d78ec..39919feb7d 100644
--- a/gnu/packages/terminals.scm
+++ b/gnu/packages/terminals.scm
@@ -1338,8 +1338,11 @@ tmux.")
(delete 'configure) ;no configure script
(replace 'build
(lambda* (#:key inputs #:allow-other-keys)
- ;; Don't fail on deprecation warnings from GCC
- (setenv "CFLAGS" "-Wno-error=deprecated-declarations")
+ ;; Don't fail on deprecation warnings from GCC or when not using
+ ;; sizeof in one of the two arguments of calloc
+ (setenv "CFLAGS"
+ (string-append "-Wno-error=deprecated-declarations "
+ "-Wno-error=calloc-transposed-args"))
;; The "kitty" sub-directory must be writable prior to
;; configuration (e.g., un-setting updates).
(for-each make-file-writable (find-files "kitty"))